require "test/unit"
require "core_assertions"
Test::Unit::TestCase.include Test::Unit::CoreAssertions
